@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::AbstractFromMeta;
 
-our $DATE = '2015-07-07'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-12-09'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -200,7 +200,7 @@ sub before_build {
    open my $fh, '<', $filename or die "File ${filename} cannot open: $!";
 
    my $abstract = $self->_get_abstract_from_meta($filename);
-   die "Can't get abstract for main module " . $filename unless $abstract;
+   return unless $abstract;
 
    $self->zilla->abstract($abstract);
    return;
@@ -221,9 +221,7 @@ sub munge_file {
     }
 
     my $abstract = $self->_get_abstract_from_meta($file->name, $file->content);
-    unless (defined $abstract) {
-        die "Can't figure out abstract for " . $file->name;
-    }
+    return unless $abstract;
 
     $content =~ s{^#\s*ABSTRACT:.*}{# ABSTRACT: $abstract}m
         or die "Can't insert abstract for " . $file->name;
@@ -247,7 +245,7 @@ Dist::Zilla::Plugin::Rinci::AbstractFromMeta - Fill out abstract from Rinci meta
 
 =head1 VERSION
 
-This document describes version 0.08 of Dist::Zilla::Plugin::Rinci::AbstractFromMeta (from Perl distribution Dist-Zilla-Plugin-Rinci-AbstractFromMeta), released on 2015-07-07.
+This document describes version 0.09 of Dist::Zilla::Plugin::Rinci::AbstractFromMeta (from Perl distribution Dist-Zilla-Plugin-Rinci-AbstractFromMeta), released on 2015-12-09.
 
 =head1 SYNOPSIS
 
